# Streamlit Disqus

[![Open in Streamlit][share_badge]][share_link] [![GitHub][github_badge]][github_link] [![PyPI][pypi_badge]][pypi_link] 

## Installation

```sh
pip install streamlit-disqus
```

## Quick usage

```python
from streamlit_disqus import st_disqus

st_disqus("streamlit-disqus-demo")
```

## Demo

Interested to see Streamlit Disqus in action? You can try it out now in [Streamlit Sharing][share_link]!

Demo's **source code** and component's **documentation** are also available there.

[![Demo preview][share_img]][share_link]


[share_badge]: https://static.streamlit.io/badges/streamlit_badge_black_white.svg
[share_link]: https://share.streamlit.io/okld/streamlit-disqus-demo/main/app.py
[share_src]: https://github.com/okld/streamlit-disqus-demo/blob/main/app.py
[share_img]: https://raw.githubusercontent.com/okld/streamlit-disqus-demo/main/app.png

[github_badge]: https://badgen.net/badge/icon/GitHub?icon=github&color=black&label
[github_link]: https://github.com/okld/streamlit-disqus

[pypi_badge]: https://badgen.net/pypi/v/streamlit-disqus?icon=pypi&color=black&label
[pypi_link]: https://pypi.org/project/streamlit-disqus
